# BarPlots
# interesting because they can be stacked. (or not, too)
# mostly straight from the website

# But the usage of geom_bar() can be quite confusing. 
# Thats because, it can be used to make a bar chart as well as a histogram. 
# Let me explain. By default, geom_bar() has the stat set to count. 
# That means, when you provide just a continuous X variable (and no Y variable),
# it tries to make a histogram out of the data.
# In order to make a bar chart create bars instead of histogram, 
# you need to do two things. Set stat=identity.  And provide both x and y 
# inside aes() where, x is either character or factor and y is numeric.

library(ggplot2)
df <- data.frame(dose=c("D0.5", "D1", "D2"),
                 len=c(4.2, 10, 29.5))
head(df)

df2 <- data.frame(supp=rep(c("VC", "OJ"), each=3),
                  dose=rep(c("D0.5", "D1", "D2"),2),
                  len=c(6.8, 15, 33, 4.2, 10, 29.5))
head(df2)

# define the basic plot:
f <- ggplot(df, aes(x = dose, y = len))

# When you are generating a 2-variable bar plot, you almost always
# want stat = "identity".  The default is stat = "count", which
# is really like a histogram.  But you want the values of the 
# y variable on the y=axis.  Values are the "identity" of the variable.
f + geom_bar()  # error:  "stat_count() must not be used with 
                #          a y aesthetic".  

# Basic bar plot
f + geom_bar(stat = "identity")
# Change fill color and add labels
f + geom_bar(stat="identity", fill="steelblue")+
  geom_text(aes(label=len), vjust=-0.3, size=3.5)+
  theme_minimal()
# Change bar plot line colors by groups
f + geom_bar(aes(color = dose),
             stat="identity", fill="white")
# Change bar plot fill colors by groups
f + geom_bar(aes(fill = dose), stat="identity")
df2
# bar plots with multiple groups:
g <- ggplot(data=df2, aes(x=dose, y=len, fill=supp)) 
# Stacked bar plot
g + geom_bar(stat = "identity") # the default is stacked
# Use position=position_dodge()
g + geom_bar(stat="identity", position=position_dodge())

# customize further with additional parameters:
ggplot(data=df2, aes(x=dose, y=len, fill=supp)) +
  geom_bar(stat="identity", position = position_dodge()) +
  geom_text(aes(label = len),vjust=1.6, color = "white",
            position = position_dodge(0.9), size = 3.5)

ggplot(data=df2, aes(x=dose, y=len, fill=supp)) +
  geom_bar(stat="identity", position = position_dodge()) +
  geom_text(aes(label = len),vjust=1, color = "white",
            position = position_dodge(0.2), size = 3.5)

# Add labels to a stacked bar chart:
# Step 1:  Sort the data by dose and supp:
library(plyr)
df_sorted <- arrange(df2, dose, supp)
head(df_sorted)  # see, it's sorted by len within dose

# Step 2:  Calculate the cumulative sum of len for each dose:
df_cumSum <- ddply(df_sorted, "dose", transform, label_ypos=cumsum(len))
head(df_cumSum)
# cool:  The y-position for the label is actually the cumulative sum of the len.


# Create the bar plot:
ggplot (data = df_cumSum, aes(x = dose, y = len, fill = supp)) +
  geom_bar(stat="identity") +
  geom_text(aes(y=label_ypos, label = len), vjust = 1.6,
            color = "white", size = 3.5)

# if you want to change the position of the y-label, you have
# to recalculate.

# This seems hokey.  Maybe there'a a less hokey way.
