# discrete X and continuous Y:  use a factor for X
# Straight from the text website, but I added a few things...

#Plot types:
#   Possible layers include:

# geom_boxplot() for box plot
# geom_violin() for violin plot
# geom_dotplot() for dot plot
# geom_jitter() for stripchart
# geom_line() for line plot
# geom_bar() for bar plot

# But wait, you are saying, didn't we look at some of these plots?
# Yes, but for only one variable.  Actually, we cheated, looked at 2-dim.
# But ggplot, for some odd reason, always assume grouped boxplots, 
# and requires both an x and a y aesthetic.
# qplot on the other hand allows you to plot just one variable.

library(ggplot2)
data("ToothGrowth")
ToothGrowth
ToothGrowth$dose <- as.factor(ToothGrowth$dose)
head(ToothGrowth)
e <- ggplot(ToothGrowth, aes(x = dose, y = len))

# e <- ggplot(ToothGrowth, aes(x = dose, y = len)) +
#   geom_point()
e
# dose is a factor, and can be used for grouping
# len is continuous--good for boxplot

class(ToothGrowth$dose) # output:  a factor
class(ToothGrowth$len)  # output:  continuous

# Default plot
e + geom_boxplot()     # output:  boxlot of x for each dose
e + stat_boxplot(coef = 1.5)  # equivalent of above

# rotate the box plot:
e + geom_boxplot() + coord_flip()

# Notched box plot
e + geom_boxplot(notch = TRUE)

# Color by group (dose)
e + geom_boxplot(aes(color = dose))
# Change fill color by group (dose)
e + geom_boxplot(aes(fill = dose))
# and you can use scale_color/fill_manual/brewer/grey, and so forth...

# color the boxplots, without regard to grouping:
e + geom_boxplot(color = "blue", fill = "orange")

# Notice in the following lines, color=dose is in the ggplot()
e1 <- ggplot(ToothGrowth, aes(x = dose, y = len, color=dose))
e1 + geom_boxplot()     # looks the same as before
                        # because dose is already an x coord
                        # so ggplot doesn't need to "group by"
                        #    in order to differentiate

# But look what happens when I use a third variable (supp)
e2 <- ggplot(ToothGrowth, aes(x = dose, y = len, color=supp))
e2 + geom_boxplot() 

# similarly, I can put the aes inside the geom
e3 <- ggplot(ToothGrowth, aes(x = dose, y = len))
e3 + geom_boxplot(aes(color = supp)) 

#box plot with  mean points:
e + geom_boxplot() +
  stat_summary(fun.y = mean, geom = "point",
               shape = 18, size = 4, color = "green")

# Box plot with multiple groups (note fill=supp as part of aes)
# We already did this earlier with color
ggplot(ToothGrowth, aes(x=dose, y=len, fill=supp)) +
  geom_boxplot()

e +geom_boxplot(aes(fill=supp))  # same thing but layered on earlier plot

# and you can use scale_fill_manual (or whatever)

# change the position: (dodge changes the width of the plot
#    to prevent overlapping)
e +geom_boxplot(aes(fill=supp), position = position_dodge(1))

# https://ggplot2.tidyverse.org/reference/position_dodge.html





