# Line Plots
# We did these before, for continuous functions
# THis is not different at all.
#  geom_line()
#  geom_step()
#  geom_path()
library(ggplot2)
# data("ToothGrowth") # not using the dataset, just copying some data

df <- data.frame(dose=c("D0.5", "D1", "D2"),
                 len=c(4.2, 10, 29.5))
head(df)

df2 <- data.frame(supp=rep(c("VC", "OJ"), each=3),
                         dose=rep(c("D0.5", "D1", "D2"),2),
                         len=c(6.8, 15, 33, 4.2, 10, 29.5))
head(df2)

p <- ggplot (data=df, aes(x=dose, y=len, group = 1))

# Why group = 1?
# From stackoverflow:
# For line graphs, the data points must be grouped so that it 
# knows which points to connect. In this case, it is simple 
# -- all points should be connected, so group=1. 
# When more variables are used and multiple lines are drawn, 
# the grouping for lines is usually done by variable.
p1 <- ggplot (data=df, aes(x=dose, y=len)) # here is without grouping

# Line:
p + geom_line()
p1+geom_line()  # this will not work, see error.
# Why did we not get this error when we used geom_line() before?
# We were working with 2 continuous varaibles.  You can't group those.



class(df$dose)  # factor--so this is the grouping variable
class(df$len)   # numeric
# Line with points:
p + geom_line() + geom_point()
p + geom_line()
# change linetype
p + geom_line(linetype = "dashed",color = "steelblue") +
  geom_point(color = "red")

p + geom_path()  # In serial order, which in this case is also seq
p + geom_step()


# Now work with df2, to group by another variable "supp"
p1 <- ggplot(df2, aes(x=dose, y=len, group=supp))

p1 +
  geom_line(aes(linetype=supp))+
  geom_point()

p1  +
  geom_line(aes(linetype=supp, color = supp))+
  geom_point(aes(shape=supp, color = supp))

# Line plot with numeric x-axis
# You can choose:  treat it as continuous or factor variable

df3 <- data.frame(supp=rep(c("VC", "OJ"), each = 3),
                  dose=rep(c("0.5", "1", "2"), 2),
                  len = c(6.8, 15, 33, 4.2, 10, 29.5))
df3  # notice that the dose is no longer "D0.5" and "D1"
     # It is defined as a string, but it's a numeric string
     # You will be able to choose to interpret it as numeric 

# x axis treated as a continuous variable:
numericDose <- as.numeric(as.vector(df3$dose))
# Just using as.numeric will only give the internal integer codes. 
# Factors are stored internally as integers.
# So convert it to a vector first, then convert to numeric and it works.

numericDose  # Now it works as planned
class(numericDose)

# Now let's add numericDose to df3, so we can use it in ggplot:
df3$numericDose = numericDose
dim(df3)  # it added another column
df3       # Yeah, there it is, and looking very numeric

# Now we can use it in gglot:
ggplot(data=df3, aes(x=numericDose, y=len, group = supp, color = supp)) +
  geom_line() + geom_point()

ggplot(data =df3, aes(x=dose, y=len, group =supp, color=supp)) +
  geom_line() +geom_point()

# Time Series (Dates on x-axis)
data(economics)
head(economics)
class(economics$date)       # type date
class(economics$unemploy)   # type integer (continuous for this purpose)
head(economics)
ggplot(data=economics, aes(x=date, y=pop))+
  geom_line()
ss <- subset(economics, date > as.Date("2006-1-1"))
ss
ggplot(data=ss, aes(x=date, y=pop))+
  geom_line()

# change line size
ggplot(data=economics, aes(x=date, y=pop, size = unemploy/pop))+
  geom_line()
# above:  line size calculated by variables, therefore inside aes
ggplot(data=ss, aes(x=date, y=pop))+
  geom_line(size = 3)
# above:  line size not related to any variables, inside geom, not aes

# plot multiple time series data:
# Solution 1
ggplot(economics, aes(x=date)) +
  geom_line(aes(y=psavert), color = "darkred") +
  geom_line(aes(y=uempmed), color = "steelblue", 
            linetype = "twodash") +
  theme_minimal()
# It doesn't show both variable names on the y-axis.
head(economics)
# Solution 2:  melt by date
library(reshape2)
df <-melt(economics[, c("date", "psavert","uempmed")], id="date")
# melt creates one  row for the date and the psavert value, 
# and another row for the date and uempmed value.
# this gives us two separate row subsets, and we can plot separately
head(economics)
head(df)
tail(df)
# Now let's plot:
ggplot(df, aes(x=date, y=value)) +
  geom_line(aes(color = variable), size=1) +
  scale_color_manual(values = c("blue", "red")) +
  theme_minimal()

# similar for area plot:
ggplot(economics, aes(x=date)) +
  geom_area(aes(y=psavert), fill = "#999999",
            color = "#999999", alpha = 0.5) +
  geom_area(aes(y = uempmed), fill = "#e69f00",
            color = "#e69f00", alpha = 0.5) +
  theme_minimal()

# If you are using the "melted" df:
# the default for grouping on the same geom_area is "stacked"
ggplot(df, aes(x=date, y=value, color = variable, fill= variable))+
  geom_area(alpha = 0.5, position = "identity") +
  scale_color_manual(values=c("lightblue","yellow")) +
  scale_fill_manual(values=c("lightblue","yellow"))
ggplot(df, aes(x=date)) +
  geom_area(aes(y=value, fill=variable), position = "identity", alpha = 0.5) +
  scale_color_manual(values=c("lightblue","yellow")) +
  scale_fill_manual(values=c("lightblue","yellow"))

