# Pie Chart is a stacked bar chart, using polar coords
# We could have included this in the one-variable charts,
# but it involved grouping, so I put it here

df <- data.frame(
  group = c("Male", "Female", "Child"),
  value = c(25, 25, 50)
)
head(df)

library(ggplot2)
# Barplot
bp<- ggplot(df, aes(x="", y=value, fill=group))+
  geom_bar(width = 1, stat = "identity")

bp   # See, it's a stacked bar chart

# The way we did barplots in the past result in separate bars.
bp1<- ggplot(df, aes(x=group, y=value)) +
  geom_bar(stat="identity")
bp1

pie <- bp + coord_polar("y", start=0)
pie

# And, of course, you can change colors
pie + scale_fill_manual(values=c("#999999", "#E69F00", "#56B4E9"))

# You can apply a theme:
pie + scale_fill_brewer(palette="Blues")+
  theme_minimal()

# And, for extra, you can create your own theme:
# See website for customizing axes and panels
blank_theme <- theme_minimal()+
  theme(
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    panel.border = element_blank(),
    panel.grid=element_blank(),
    axis.ticks = element_blank(),
    plot.title=element_text(size=14, face="bold")
  )

# And, you can apply that theme, just like the built-in ones:
pie + scale_fill_brewer(palette="Reds") + blank_theme

# and you can further customize the chart:
library(scales)
pie + scale_fill_brewer(palette = "BuGn") + blank_theme +
  geom_text(aes(y = value/3 + c(0, cumsum(value)[-length(value)]),
                label = percent(value/100)), size = 5)

# and make it even blanker
pie + scale_fill_grey() +  blank_theme +
  theme(axis.text.x=element_blank()) +
  geom_text(aes(y = value/3 + c(0, cumsum(value)[-length(value)]), 
                label = percent(value/100)), size=5)

# needs transparency:
bp1<- ggplot(df, aes(x="", y=value, fill=group))+
  geom_bar(width = 1, stat = "identity", alpha = 0.5)
bp1
pie1 <- bp1 + coord_polar("y", start=0)
pie1

pie1 + scale_fill_grey() +  blank_theme +
  theme(axis.text.x=element_blank()) +
  geom_text(aes(y = value/3 + c(0, cumsum(value)[-length(value)]), 
                label = percent(value/100)), size=5)
# better!
