# Survival curves are called that, because they can model
# the survival of patients after treatment, over time.
# Survival plots are often used in marketing, to see how
# many customers will "survive" as customers, over time.

# We'll use the ggplot2 extension "survival"
# Install.packages("survival")
library("ggplot2") # you only need this if you'll use a ggplot function
library("scales")  # need for the guides function
library("survival")
library("GGally")  # This is required for the ggsurv function
data(lung)
lung  # "censored" means patient survived the study time period
# We are interested in  time, status, sex
# Fit survival functions
# survfit creates a "survfit" object, required by ggsurv
fit <- survfit(Surv(time, status) ~ sex, data = lung)
# The tilde mean "by", as in "time and status grouped by sex"
# Plot survival curves
# ggsurve takes the survfit object and creates a plot
fit.p <- ggsurv(fit)  
fit.p  # display the plot

# change the legend
# make sure that ggplot2 and scales are activated (library)
fit.p + guides(linetype = FALSE) +
  scale_colour_discrete(name   = 'Sex', breaks = c(1,2), 
                        labels = c('Male', 'Female'))
