# Violin plots are similar to box plots except that they also show 
# the kernel probability density of the data at different values.
# Kind of like getting a bonus density plot with your boxplot

# set up your data and basic plot:
library(ggplot2)
data("ToothGrowth")
ToothGrowth$dose <- as.factor(ToothGrowth$dose)
head(ToothGrowth)
e <- ggplot(ToothGrowth, aes(x = dose, y = len))

# basic violin plot:
e + geom_violin()
e + geom_violin() + coord_flip()  # sideways, if you like that better
e + geom_violin(trim = FALSE, fill = "steelblue") # keep the "tails"

# add summary statistics.  So you have to add a layer of stat_summary
# http://ggplot2.tidyverse.org/reference/stat_summary.html

e + geom_violin(trim = FALSE) + 
  stat_summary(fun.y="mean", geom="point", 
               shape = 23, size = 2, color = "blue")

# show the std-dev around the mean too
e + geom_violin(trim = FALSE) + 
  stat_summary(fun.data ="mean_sdl",  fun.args = list(mult=2), 
               geom="pointrange", color = "red")
# "mult = 1" means "how many sigmas do I want to show?" default = 2

e + geom_violin(trim = FALSE) + 
  stat_summary(fun.data ="mean_sdl",  
               geom="pointrange", color = "red")

# Color by group (dose) 
e + geom_violin(aes(color = dose), trim = FALSE)
# obviously, you can also change the fill by group.  in the aes()


# Combine with box plot
e + geom_violin(trim = FALSE) + 
  geom_boxplot(width = 0.2)

# and you can fully customize the colors, either inside the aes
# or, for a uniform coloring across groups, outside the aes

# play around with the legend position
p <- ggplot(ToothGrowth, aes(x=dose, y=len, fill=dose)) +
  geom_violin(trim=FALSE)  
p

# this plots the same thing:
p <- ggplot(ToothGrowth, aes(x=dose, y=len)) +
  geom_violin(aes(fill = dose), trim=FALSE)
p


p <- ggplot(ToothGrowth, aes(x=dose, y=len, fill=dose)) +
  geom_violin(trim=FALSE)
p + theme(legend.position="top")
p + theme(legend.position="bottom")
p + theme(legend.position="none") # Remove legend

# change the order of items in the legend
p + scale_x_discrete(limits=c("2", "0.5", "1"))

