# Correlation Matrix Visualization
# Two packages to support correlation:  GGally and ggcorplot
#  Important:  These are extensions to ggplot2, and don't follow
#              the same syntax, but can interact with ggplot2

# We also saw some heat maps in RBase earlier.
# and you can see how to do this is regular ggplot:
# http://www.sthda.com/english/wiki/ggplot2-quick-correlation-matrix-heatmap-r-software-and-data-visualization

# install.packages("GGally")  # I'm commenting this because it
                              # only has to be done once.
# install.packages("ggcorrplot")

# GGally examples
library(GGally)
library(ggcorrplot)
# Prepare some data
mydata <- mtcars[, c(1,3,4,5,6,7)] # only the numeric data
# Correlation
ggcorr(mydata, palette = "RdBu", label = TRUE)
ggpairs(mydata)


# Include "cyl" in the data
mydata2 <- mtcars[, c(1,2,3,4,5,6,7)]
# Correlation plot
ggcorr(mydata2, palette = "RdBu", label = TRUE)
ggpairs(mydata2)

# and now let's try it with cyl as a factor
mydata3 <- mtcars[, c(1,2,3,4,5,6,7)]
class(mydata3$cyl)  # it's numeric--good for correlation
mydata3$cyl <- as.factor(mydata3$cyl)
# Correlation plot
ggcorr(mydata3, palette = "RdBu", label = TRUE)
# ignores the categorical variable (cyl), which is good
# But we can now use cyl to color ggcorr!
ggpairs(mydata3, ggplot2::aes(color = cyl))
# pretty cool!  But it includes cyl in the matrix--not good
ggpairs(mydata3, columns = c(1, 3:7),ggplot2::aes(color = cyl))
# and now it doesn't include cyl, but still colors by cyl

# ggcorplot  (make sure it's installed and library("ggcorrplot"))
library("ggcorrplot")
mydata <- mtcars[, c(1,3,4,5,6,7)] # only the numeric data
corr <- round(cor(mydata), 1)  # cor is an R function.
# The second parameter is how many decimal places to round to
# cor returns a matrix.  So corr is a matrix.

head(corr[, 1:6],3)
corr <- round(cor(mydata), 2)  # cor is an R function.
head(corr[, 1:6],4)
head(corr)
class(corr)

head(corr, 3)


p.mat <- cor_pmat(mydata)
head(p.mat[, 1:4],3)
ggcorrplot(corr)

# method = "circle"  ( I think the squares are clearer.)
ggcorrplot(corr, method = "circle")

# Reordering the correlation matrix
# Make the strong correlations easier to find
# --------------------------------
# using hierarchical clustering
ggcorrplot(corr, hc.order = TRUE, outline.col = "white")

# Types of correlogram layout
# --------------------------------
# Get the lower triangle
ggcorrplot(corr, hc.order = TRUE, type = "lower",
           outline.col = "white")

# Get the upper triangle
ggcorrplot(corr, hc.order = TRUE, type = "upper",
           outline.col = "white")

# Add correlation coefficients
# --------------------------------
# argument lab = TRUE
ggcorrplot(corr, hc.order = TRUE, type = "lower",
           lab = TRUE)

# Leave blank on no significant coefficient
ggcorrplot(corr, p.mat = p.mat, hc.order = TRUE,
           type = "lower", insig = "blank")

